@@ -6,7 +6,7 @@ only exposed for testing, the CLI, and type hinting.
 
 from importlib.metadata import version
 
-from .core import group, problem, test_case
+from .core import group, problem, test_case, test_cases
 
-__all__ = ("problem", "test_case", "group")
+__all__ = ("problem", "test_case", "test_cases", "group")
 __version__ = version(__name__)  # type: ignore
