@@ -11,11 +11,12 @@ from unittest import TestResult, TestSuite
 from dataclasses_json import dataclass_json
 
 from ..core import AgaTestCase
+from ..util import limited_traceback
 
 
 @dataclass_json
 @dataclass
-class _GradescopeTestJson:
+class GradescopeTestJson:
     """The JSON schema for a single Test.
 
     Attributes
@@ -68,7 +69,7 @@ class GradescopeJson:
         Whether to show stdout for the tests. Same options as for visibility.
     """
 
-    tests: List[_GradescopeTestJson]
+    tests: List[GradescopeTestJson]
     score: Optional[float] = None
     execution_time: Optional[int] = None
     output: Optional[str] = None
@@ -93,32 +94,33 @@ class _GradescopeTestResult(TestResult):
         """Get the appropriate visibility string for Gradescope's JSON format."""
         return "hidden" if hidden else "visible"
 
-    def _test_json(self, test: AgaTestCase) -> _GradescopeTestJson:
+    def _test_json(self, test: AgaTestCase) -> GradescopeTestJson:
         """Construct the test json schema for a test, with _no_ output."""
         metadata = test.metadata()
         visibility = self._visibility_string(metadata.hidden)
 
-        return _GradescopeTestJson(
+        return GradescopeTestJson(
             max_score=metadata.max_score,
             name=metadata.name,
             score=metadata.max_score,
             visibility=visibility,
         )
 
-    def _fail_json(self, test: AgaTestCase, err) -> _GradescopeTestJson:  # type: ignore
+    def _fail_json(self, test: AgaTestCase, err) -> GradescopeTestJson:  # type: ignore
         """Construct the test json schema for a failure."""
         json = self._test_json(test)
-        json.output = f"Your submission didn't give the output we expected: {err[1]}"
+        json.output = str(err[1])
         json.score = 0.0
 
         return json
 
-    def _err_json(self, test: AgaTestCase, err) -> _GradescopeTestJson:  # type: ignore
+    def _err_json(self, test: AgaTestCase, err) -> GradescopeTestJson:  # type: ignore
         """Construct the test json schema for an error."""
         json = self._test_json(test)
-        json.output = (
-            f"A python error occured while running your submission: "
-            f"{err[0].__name__}: {err[1]}"
+        json.output = test.metadata().error_msg.format(
+            type=err[0].__name__,
+            message=err[1],
+            traceback=limited_traceback(err[2]),
         )
         json.score = 0.0
 
